==> ejc-bfyjerp-api-3.0.0-20250314.065440-178-sources.jar: com/ejianc/business/bid/vo/WinningRegistrationVO.java <==
package com.ejianc.business.bid.vo;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 投标管理-中标登记
 * 
 * @author generator
 * 
 */
public class WinningRegistrationVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 编码
    private Long registrationId; // 项目报名表Id
    private Long opportunityId; // 商机登记表Id
    private Long opportunityBillCode; // 商机登记单据编码
    private String engineeringName; // 工程名称
    private String memo; // 备注
    private Long pubUnitId; // 发包单位
    private String pubUnitName; // 发包单位名称
    private String pubUnitCode; // 发包单位编码
    private Long contractualModelId; // 承包方式id
    private String contractualModelName; // 承包方式
    private Long affiliateMemberId; // 所属会员id
    private String affiliateMemberName; // 所属会员名称
    private Long provinceId; // 项目所属省份id
    private String provinceCode; // 项目所属省份编码
    private String provinceName; // 省份名称
    private Long cityId; // 地级市id
    private String cityCode; // 地级市编码
    private String cityName; // 地级市名称
    private Long bidWinnerId; // 中标单位id
    private String bidWinnerCode; // 中标单位编码
    private String bidWinner; // 中标单位
    private BigDecimal bidMny; // 中标价
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date bidDate; // 中标日期
    private String collectionTypeName; // 征收方式
    private BigDecimal comprehensiveTaxRate; // 综合税率
    private BigDecimal managementFee; // 管理费收取
    private BigDecimal companyPartPercent; // 公司部分
    private BigDecimal projectManagerPartPercent; // 业务经理部分+基础提成
    private BigDecimal thirdPartPercent; // 第三方部分
    private String thirdPartRecPersonName; // 第三方收款人信息
    private Integer billState; // 单据状态
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date commitDate; // 提交日期
    private String commitUserName; // 提交人名称
    private String commitUserCode; // 提交人账号
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date effectiveDate; // 生效日期
    private Long orgId; // 所属组织id
    private String orgCode; // 所属组织编码
    private String orgName; // 所属组织名称
    private Long employeeId; // 编制人id
    private String employeeName; // 编制人名称
    private String accountUser; // 姓名
    private String accountName; // 账户
    private String accountNum; // 开户行

    public String getAccountUser() {
        return accountUser;
    }

    public void setAccountUser(String accountUser) {
        this.accountUser = accountUser;
    }

    public String getAccountName() {
        return accountName;
    }

    public void setAccountName(String accountName) {
        this.accountName = accountName;
    }

    public String getAccountNum() {
        return accountNum;
    }

    public void setAccountNum(String accountNum) {
        this.accountNum = accountNum;
    }

    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }

    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    @ReferSerialTransfer(referCode = "bfyj-bid-projectRegistration")
    public Long getRegistrationId() {
        return registrationId;
    }
    @ReferDeserialTransfer
    public void setRegistrationId(Long registrationId) {
        this.registrationId = registrationId;
    }
    @ReferSerialTransfer(referCode = "bfyj-bid-busOpportunity")
    public Long getOpportunityId() {
        return opportunityId;
    }
    @ReferDeserialTransfer
    public void setOpportunityId(Long opportunityId) {
        this.opportunityId = opportunityId;
    }
    public Long getOpportunityBillCode() {
        return opportunityBillCode;
    }

    public void setOpportunityBillCode(Long opportunityBillCode) {
        this.opportunityBillCode = opportunityBillCode;
    }
    public String getEngineeringName() {
        return engineeringName;
    }

    public void setEngineeringName(String engineeringName) {
        this.engineeringName = engineeringName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    @ReferSerialTransfer(referCode = "support-customer")
    public Long getPubUnitId() {
        return pubUnitId;
    }
    @ReferDeserialTransfer
    public void setPubUnitId(Long pubUnitId) {
        this.pubUnitId = pubUnitId;
    }
    public String getPubUnitName() {
        return pubUnitName;
    }

    public void setPubUnitName(String pubUnitName) {
        this.pubUnitName = pubUnitName;
    }
    public String getPubUnitCode() {
        return pubUnitCode;
    }

    public void setPubUnitCode(String pubUnitCode) {
        this.pubUnitCode = pubUnitCode;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getContractualModelId() {
        return contractualModelId;
    }
    @ReferDeserialTransfer
    public void setContractualModelId(Long contractualModelId) {
        this.contractualModelId = contractualModelId;
    }
    public String getContractualModelName() {
        return contractualModelName;
    }

    public void setContractualModelName(String contractualModelName) {
        this.contractualModelName = contractualModelName;
    }
    @ReferSerialTransfer(referCode = "office-member")
    public Long getAffiliateMemberId() {
        return affiliateMemberId;
    }
    @ReferDeserialTransfer
    public void setAffiliateMemberId(Long affiliateMemberId) {
        this.affiliateMemberId = affiliateMemberId;
    }
    public String getAffiliateMemberName() {
        return affiliateMemberName;
    }

    public void setAffiliateMemberName(String affiliateMemberName) {
        this.affiliateMemberName = affiliateMemberName;
    }
    @ReferSerialTransfer(referCode = "bfyj-bid-area")
    public Long getProvinceId() {
        return provinceId;
    }
    @ReferDeserialTransfer
    public void setProvinceId(Long provinceId) {
        this.provinceId = provinceId;
    }
    public String getProvinceCode() {
        return provinceCode;
    }

    public void setProvinceCode(String provinceCode) {
        this.provinceCode = provinceCode;
    }
    public String getProvinceName() {
        return provinceName;
    }

    public void setProvinceName(String provinceName) {
        this.provinceName = provinceName;
    }
    @ReferSerialTransfer(referCode = "bfyj-bid-area")
    public Long getCityId() {
        return cityId;
    }
    @ReferDeserialTransfer
    public void setCityId(Long cityId) {
        this.cityId = cityId;
    }
    public String getCityCode() {
        return cityCode;
    }

    public void setCityCode(String cityCode) {
        this.cityCode = cityCode;
    }
    public String getCityName() {
        return cityName;
    }

    public void setCityName(String cityName) {
        this.cityName = cityName;
    }
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getBidWinnerId() {
        return bidWinnerId;
    }
    @ReferDeserialTransfer
    public void setBidWinnerId(Long bidWinnerId) {
        this.bidWinnerId = bidWinnerId;
    }
    public String getBidWinnerCode() {
        return bidWinnerCode;
    }

    public void setBidWinnerCode(String bidWinnerCode) {
        this.bidWinnerCode = bidWinnerCode;
    }
    public String getBidWinner() {
        return bidWinner;
    }

    public void setBidWinner(String bidWinner) {
        this.bidWinner = bidWinner;
    }
    public BigDecimal getBidMny() {
        return bidMny;
    }

    public void setBidMny(BigDecimal bidMny) {
        this.bidMny = bidMny;
    }
    public Date getBidDate() {
        return bidDate;
    }

    public void setBidDate(Date bidDate) {
        this.bidDate = bidDate;
    }
    public String getCollectionTypeName() {
        return collectionTypeName;
    }

    public void setCollectionTypeName(String collectionTypeName) {
        this.collectionTypeName = collectionTypeName;
    }
    public BigDecimal getComprehensiveTaxRate() {
        return comprehensiveTaxRate;
    }

    public void setComprehensiveTaxRate(BigDecimal comprehensiveTaxRate) {
        this.comprehensiveTaxRate = comprehensiveTaxRate;
    }
    public BigDecimal getManagementFee() {
        return managementFee;
    }

    public void setManagementFee(BigDecimal managementFee) {
        this.managementFee = managementFee;
    }
    public BigDecimal getCompanyPartPercent() {
        return companyPartPercent;
    }

    public void setCompanyPartPercent(BigDecimal companyPartPercent) {
        this.companyPartPercent = companyPartPercent;
    }
    public BigDecimal getProjectManagerPartPercent() {
        return projectManagerPartPercent;
    }

    public void setProjectManagerPartPercent(BigDecimal projectManagerPartPercent) {
        this.projectManagerPartPercent = projectManagerPartPercent;
    }
    public BigDecimal getThirdPartPercent() {
        return thirdPartPercent;
    }

    public void setThirdPartPercent(BigDecimal thirdPartPercent) {
        this.thirdPartPercent = thirdPartPercent;
    }
    public String getThirdPartRecPersonName() {
        return thirdPartRecPersonName;
    }

    public void setThirdPartRecPersonName(String thirdPartRecPersonName) {
        this.thirdPartRecPersonName = thirdPartRecPersonName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Date getCommitDate() {
        return commitDate;
    }

    public void setCommitDate(Date commitDate) {
        this.commitDate = commitDate;
    }
    public String getCommitUserName() {
        return commitUserName;
    }

    public void setCommitUserName(String commitUserName) {
        this.commitUserName = commitUserName;
    }
    public String getCommitUserCode() {
        return commitUserCode;
    }

    public void setCommitUserCode(String commitUserCode) {
        this.commitUserCode = commitUserCode;
    }
    public Date getEffectiveDate() {
        return effectiveDate;
    }

    public void setEffectiveDate(Date effectiveDate) {
        this.effectiveDate = effectiveDate;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    
}

==> ejc-bfyjerp-api-3.0.0-20251216.060628-315-sources.jar: com/ejianc/business/bid/vo/WinningRegistrationVO.java <==
package com.ejianc.business.bid.vo;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 投标管理-中标登记
 * 
 * @author generator
 * 
 */
public class WinningRegistrationVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 编码
    private Long registrationId; // 项目报名表Id
    private Long opportunityId; // 商机登记表Id
    private Long opportunityBillCode; // 商机登记单据编码
    private String engineeringName; // 工程名称
    private String memo; // 备注
    private Long pubUnitId; // 发包单位
    private String pubUnitName; // 发包单位名称
    private String pubUnitCode; // 发包单位编码
    private Long contractualModelId; // 承包方式id
    private String contractualModelName; // 承包方式
    private Long affiliateMemberId; // 所属会员id
    private String affiliateMemberName; // 所属会员名称
    private Long provinceId; // 项目所属省份id
    private String provinceCode; // 项目所属省份编码
    private String provinceName; // 省份名称
    private Long cityId; // 地级市id
    private String cityCode; // 地级市编码
    private String cityName; // 地级市名称
    private Long bidWinnerId; // 中标单位id
    private String bidWinnerCode; // 中标单位编码
    private String bidWinner; // 中标单位
    private BigDecimal bidMny; // 中标价
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date bidDate; // 中标日期
    private String collectionTypeName; // 征收方式
    private BigDecimal comprehensiveTaxRate; // 综合税率
    private BigDecimal managementFee; // 管理费收取
    private BigDecimal companyPartPercent; // 公司部分
    private BigDecimal projectManagerPartPercent; // 业务经理部分+基础提成
    private BigDecimal thirdPartPercent; // 第三方部分
    private String thirdPartRecPersonName; // 第三方收款人信息
    private Integer billState; // 单据状态
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date commitDate; // 提交日期
    private String commitUserName; // 提交人名称
    private String commitUserCode; // 提交人账号
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date effectiveDate; // 生效日期
    private Long orgId; // 所属组织id
    private String orgCode; // 所属组织编码
    private String orgName; // 所属组织名称
    private Long employeeId; // 编制人id
    private String employeeName; // 编制人名称
    private String accountUser; // 姓名
    private String accountName; // 账户
    private String accountNum; // 开户行
    private Long followPersonId; // 业务经理id
    private String followPerson; // 业务经理

    @ReferSerialTransfer(referCode = "idm-employee")
    public Long getFollowPersonId() {
        return followPersonId;
    }
    @ReferDeserialTransfer
    public void setFollowPersonId(Long followPersonId) {
        this.followPersonId = followPersonId;
    }
    public String getFollowPerson() {
        return followPerson;
    }

    public void setFollowPerson(String followPerson) {
        this.followPerson = followPerson;
    }
    public String getAccountUser() {
        return accountUser;
    }

    public void setAccountUser(String accountUser) {
        this.accountUser = accountUser;
    }

    public String getAccountName() {
        return accountName;
    }

    public void setAccountName(String accountName) {
        this.accountName = accountName;
    }

    public String getAccountNum() {
        return accountNum;
    }

    public void setAccountNum(String accountNum) {
        this.accountNum = accountNum;
    }

    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }

    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    @ReferSerialTransfer(referCode = "bfyj-bid-projectRegistration")
    public Long getRegistrationId() {
        return registrationId;
    }
    @ReferDeserialTransfer
    public void setRegistrationId(Long registrationId) {
        this.registrationId = registrationId;
    }
    @ReferSerialTransfer(referCode = "bfyj-bid-busOpportunity")
    public Long getOpportunityId() {
        return opportunityId;
    }
    @ReferDeserialTransfer
    public void setOpportunityId(Long opportunityId) {
        this.opportunityId = opportunityId;
    }
    public Long getOpportunityBillCode() {
        return opportunityBillCode;
    }

    public void setOpportunityBillCode(Long opportunityBillCode) {
        this.opportunityBillCode = opportunityBillCode;
    }
    public String getEngineeringName() {
        return engineeringName;
    }

    public void setEngineeringName(String engineeringName) {
        this.engineeringName = engineeringName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    @ReferSerialTransfer(referCode = "support-customer")
    public Long getPubUnitId() {
        return pubUnitId;
    }
    @ReferDeserialTransfer
    public void setPubUnitId(Long pubUnitId) {
        this.pubUnitId = pubUnitId;
    }
    public String getPubUnitName() {
        return pubUnitName;
    }

    public void setPubUnitName(String pubUnitName) {
        this.pubUnitName = pubUnitName;
    }
    public String getPubUnitCode() {
        return pubUnitCode;
    }

    public void setPubUnitCode(String pubUnitCode) {
        this.pubUnitCode = pubUnitCode;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getContractualModelId() {
        return contractualModelId;
    }
    @ReferDeserialTransfer
    public void setContractualModelId(Long contractualModelId) {
        this.contractualModelId = contractualModelId;
    }
    public String getContractualModelName() {
        return contractualModelName;
    }

    public void setContractualModelName(String contractualModelName) {
        this.contractualModelName = contractualModelName;
    }
    @ReferSerialTransfer(referCode = "office-member")
    public Long getAffiliateMemberId() {
        return affiliateMemberId;
    }
    @ReferDeserialTransfer
    public void setAffiliateMemberId(Long affiliateMemberId) {
        this.affiliateMemberId = affiliateMemberId;
    }
    public String getAffiliateMemberName() {
        return affiliateMemberName;
    }

    public void setAffiliateMemberName(String affiliateMemberName) {
        this.affiliateMemberName = affiliateMemberName;
    }
    @ReferSerialTransfer(referCode = "bfyj-bid-area")
    public Long getProvinceId() {
        return provinceId;
    }
    @ReferDeserialTransfer
    public void setProvinceId(Long provinceId) {
        this.provinceId = provinceId;
    }
    public String getProvinceCode() {
        return provinceCode;
    }

    public void setProvinceCode(String provinceCode) {
        this.provinceCode = provinceCode;
    }
    public String getProvinceName() {
        return provinceName;
    }

    public void setProvinceName(String provinceName) {
        this.provinceName = provinceName;
    }
    @ReferSerialTransfer(referCode = "bfyj-bid-area")
    public Long getCityId() {
        return cityId;
    }
    @ReferDeserialTransfer
    public void setCityId(Long cityId) {
        this.cityId = cityId;
    }
    public String getCityCode() {
        return cityCode;
    }

    public void setCityCode(String cityCode) {
        this.cityCode = cityCode;
    }
    public String getCityName() {
        return cityName;
    }

    public void setCityName(String cityName) {
        this.cityName = cityName;
    }
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getBidWinnerId() {
        return bidWinnerId;
    }
    @ReferDeserialTransfer
    public void setBidWinnerId(Long bidWinnerId) {
        this.bidWinnerId = bidWinnerId;
    }
    public String getBidWinnerCode() {
        return bidWinnerCode;
    }

    public void setBidWinnerCode(String bidWinnerCode) {
        this.bidWinnerCode = bidWinnerCode;
    }
    public String getBidWinner() {
        return bidWinner;
    }

    public void setBidWinner(String bidWinner) {
        this.bidWinner = bidWinner;
    }
    public BigDecimal getBidMny() {
        return bidMny;
    }

    public void setBidMny(BigDecimal bidMny) {
        this.bidMny = bidMny;
    }
    public Date getBidDate() {
        return bidDate;
    }

    public void setBidDate(Date bidDate) {
        this.bidDate = bidDate;
    }
    public String getCollectionTypeName() {
        return collectionTypeName;
    }

    public void setCollectionTypeName(String collectionTypeName) {
        this.collectionTypeName = collectionTypeName;
    }
    public BigDecimal getComprehensiveTaxRate() {
        return comprehensiveTaxRate;
    }

    public void setComprehensiveTaxRate(BigDecimal comprehensiveTaxRate) {
        this.comprehensiveTaxRate = comprehensiveTaxRate;
    }
    public BigDecimal getManagementFee() {
        return managementFee;
    }

    public void setManagementFee(BigDecimal managementFee) {
        this.managementFee = managementFee;
    }
    public BigDecimal getCompanyPartPercent() {
        return companyPartPercent;
    }

    public void setCompanyPartPercent(BigDecimal companyPartPercent) {
        this.companyPartPercent = companyPartPercent;
    }
    public BigDecimal getProjectManagerPartPercent() {
        return projectManagerPartPercent;
    }

    public void setProjectManagerPartPercent(BigDecimal projectManagerPartPercent) {
        this.projectManagerPartPercent = projectManagerPartPercent;
    }
    public BigDecimal getThirdPartPercent() {
        return thirdPartPercent;
    }

    public void setThirdPartPercent(BigDecimal thirdPartPercent) {
        this.thirdPartPercent = thirdPartPercent;
    }
    public String getThirdPartRecPersonName() {
        return thirdPartRecPersonName;
    }

    public void setThirdPartRecPersonName(String thirdPartRecPersonName) {
        this.thirdPartRecPersonName = thirdPartRecPersonName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Date getCommitDate() {
        return commitDate;
    }

    public void setCommitDate(Date commitDate) {
        this.commitDate = commitDate;
    }
    public String getCommitUserName() {
        return commitUserName;
    }

    public void setCommitUserName(String commitUserName) {
        this.commitUserName = commitUserName;
    }
    public String getCommitUserCode() {
        return commitUserCode;
    }

    public void setCommitUserCode(String commitUserCode) {
        this.commitUserCode = commitUserCode;
    }
    public Date getEffectiveDate() {
        return effectiveDate;
    }

    public void setEffectiveDate(Date effectiveDate) {
        this.effectiveDate = effectiveDate;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    
}
